ktch
============================================

ktch is a python package for model-based morphometrics.


.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Getting Started

   installation

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Tutorials

   tutorials/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: How-to Guides

   how-to/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Explanation

   explanation/index

.. toctree::
   :maxdepth: 2
   :hidden:
   :caption: Reference

   api/index


`Installation <installation.html>`_
-------------------------------------------------

Get started by installing ktch.

`Tutorials <tutorials/index.html>`_
-------------------------------------------------

Step-by-step guides for learning ktch through hands-on examples.

`How-to Guides <how-to/index.html>`_
-------------------------------------------------

Task-oriented guides for common operations.

`Explanation <explanation/index.html>`_
-------------------------------------------------

Conceptual explanations of morphometric methods and theory.

`API Reference <api/index.html>`_
-------------------------------------------------

Complete API documentation for all classes, functions, and modules.
